[U-Boot] [PATCH] tegra: paz00: fix typo in SD slot CD detect GPIO

Stephen Warren swarren at wwwdotorg.org
Tue May 15 23:58:11 CEST 2012


From: Stephen Warren <swarren at nvidia.com>

Signed-off-by: Stephen Warren <swarren at nvidia.com>
---
 board/compal/paz00/paz00.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/board/compal/paz00/paz00.c b/board/compal/paz00/paz00.c
index 3b48917..b07ce11 100644
--- a/board/compal/paz00/paz00.c
+++ b/board/compal/paz00/paz00.c
@@ -55,8 +55,8 @@ static void pin_mux_mmc(void)
 
 	/* For power GPIO PV1 */
 	pinmux_tristate_disable(PINGRP_UAC);
-	/* For CD GPIO PI5 */
-	pinmux_tristate_disable(PINGRP_ATC);
+	/* For CD GPIO PV5 */
+	pinmux_tristate_disable(PINGRP_GPV);
 }
 
 /* this is a weak define that we are overriding */
@@ -74,7 +74,7 @@ int board_mmc_init(bd_t *bd)
 
 	debug("board_mmc_init: init SD slot\n");
 	/* init dev 3, SD slot, with 4-bit bus */
-	tegra2_mmc_init(3, 4, GPIO_PV1, GPIO_PI5);
+	tegra2_mmc_init(3, 4, GPIO_PV1, GPIO_PV5);
 
 	return 0;
 }
-- 
1.7.0.4



More information about the U-Boot mailing list